@@ -30,9 +30,6 @@
 
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include <tiff.h>
-#include <tiffio.h>
-#include <gconf/gconf-client.h>
 
 #include "gcm-calibrate.h"
 #include "gcm-xyz.h"
@@ -42,6 +39,7 @@
 #include "gcm-brightness.h"
 #include "gcm-colorimeter.h"
 #include "gcm-calibrate-dialog.h"
+#include "gcm-exif.h"
 
 #include "egg-debug.h"
 
@@ -77,7 +75,7 @@ struct _GcmCalibratePrivate
 	gchar				*serial;
 	gchar				*device;
 	gchar				*working_path;
-	GConfClient			*gconf_client;
+	GSettings			*settings;
 };
 
 enum {
@@ -206,6 +204,15 @@ gcm_calibrate_get_filename_result (GcmCalibrate *calibrate)
 	return calibrate->priv->filename_result;
 }
 
+/**
+ * gcm_calibrate_get_working_path:
+ **/
+const gchar *
+gcm_calibrate_get_working_path (GcmCalibrate *calibrate)
+{
+	return calibrate->priv->working_path;
+}
+
 /**
  * gcm_calibrate_set_basename:
  **/
@@ -241,7 +248,7 @@ gcm_calibrate_set_basename (GcmCalibrate *calibrate)
 		g_string_append_printf (basename, " - %s", serial);
 	g_string_append_printf (basename, " (%04i-%02i-%02i)", date->year, date->month, date->day);
 
-	/* maybe configure in GConf? */
+	/* maybe configure in GSettings? */
 	if (0)
 		g_string_append_printf (basename, " [%s]", timespec);
 
@@ -327,28 +334,25 @@ out:
 gboolean
 gcm_calibrate_set_from_exif (GcmCalibrate *calibrate, const gchar *filename, GError **error)
 {
-	const gchar *manufacturer = NULL;
-	const gchar *model = NULL;
+	const gchar *manufacturer;
+	const gchar *model;
+	const gchar *serial;
 	gchar *description = NULL;
-	const gchar *serial = NULL;
-	TIFF *tiff;
-	gboolean ret = TRUE;
+	gboolean ret;
+	GcmExif *exif;
+	GFile *file;
 
-	/* open file */
-	tiff = TIFFOpen (filename, "r");
-	TIFFGetField (tiff,TIFFTAG_MAKE, &manufacturer);
-	TIFFGetField (tiff,TIFFTAG_MODEL, &model);
-	TIFFGetField (tiff,TIFFTAG_CAMERASERIALNUMBER, &serial);
-
-	/* we failed to get data */
-	if (manufacturer == NULL || model == NULL) {
-		g_set_error (error,
-			     GCM_CALIBRATE_ERROR,
-			     GCM_CALIBRATE_ERROR_NO_DATA,
-			     "failed to get EXIF data from TIFF");
-		ret = FALSE;
+	/* parse file */
+	exif = gcm_exif_new ();
+	file = g_file_new_for_path (filename);
+	ret = gcm_exif_parse (exif, file, error);
+	if (!ret)
 		goto out;
-	}
+
+	/* get data */
+	manufacturer = gcm_exif_get_manufacturer (exif);
+	model = gcm_exif_get_model (exif);
+	serial = gcm_exif_get_serial (exif);
 
 	/* do the best we can */
 	description = g_strdup_printf ("%s - %s", manufacturer, model);
@@ -364,8 +368,9 @@ gcm_calibrate_set_from_exif (GcmCalibrate *calibrate, const gchar *filename, GEr
 		g_object_set (calibrate, "serial", serial, NULL);
 
 out:
+	g_object_unref (file);
+	g_object_unref (exif);
 	g_free (description);
-	TIFFClose (tiff);
 	return ret;
 }
 
@@ -498,7 +503,7 @@ gcm_calibrate_get_precision (GcmCalibrate *calibrate, GError **error)
 		g_set_error_literal (error,
 				     GCM_CALIBRATE_ERROR,
 				     GCM_CALIBRATE_ERROR_USER_ABORT,
-				     "user did not choose precision type and ask is specified in GConf");
+				     "user did not choose precision type and ask is specified in GSettings");
 		goto out;
 	}
 
@@ -605,7 +610,7 @@ gcm_calibrate_display (GcmCalibrate *calibrate, GtkWindow *window, GError **erro
 	}
 
 	/* get default precision */
-	precision = gconf_client_get_string (priv->gconf_client, GCM_SETTINGS_CALIBRATION_LENGTH, NULL);
+	precision = g_settings_get_string (priv->settings, GCM_SETTINGS_CALIBRATION_LENGTH);
 	priv->precision = gcm_calibrate_precision_from_string (precision);
 	if (priv->precision == GCM_CALIBRATE_PRECISION_UNKNOWN) {
 		priv->precision = gcm_calibrate_get_precision (calibrate, error);
@@ -919,7 +924,7 @@ gcm_calibrate_printer (GcmCalibrate *calibrate, GtkWindow *window, GError **erro
 	}
 
 	/* get default precision */
-	precision = gconf_client_get_string (priv->gconf_client, GCM_SETTINGS_CALIBRATION_LENGTH, NULL);
+	precision = g_settings_get_string (priv->settings, GCM_SETTINGS_CALIBRATION_LENGTH);
 	priv->precision = gcm_calibrate_precision_from_string (precision);
 	if (priv->precision == GCM_CALIBRATE_PRECISION_UNKNOWN) {
 		priv->precision = gcm_calibrate_get_precision (calibrate, error);
@@ -1090,7 +1095,7 @@ gcm_calibrate_device (GcmCalibrate *calibrate, GtkWindow *window, GError **error
 	g_object_get (priv->calibrate_dialog, "reference-kind", &priv->reference_kind, NULL);
 
 	/* get default precision */
-	precision = gconf_client_get_string (priv->gconf_client, GCM_SETTINGS_CALIBRATION_LENGTH, NULL);
+	precision = g_settings_get_string (priv->settings, GCM_SETTINGS_CALIBRATION_LENGTH);
 	priv->precision = gcm_calibrate_precision_from_string (precision);
 	if (priv->precision == GCM_CALIBRATE_PRECISION_UNKNOWN) {
 		priv->precision = gcm_calibrate_get_precision (calibrate, error);
@@ -1522,8 +1527,8 @@ gcm_calibrate_init (GcmCalibrate *calibrate)
 	// FIXME: this has to be per-run specific
 	calibrate->priv->working_path = g_strdup ("/tmp");
 
-	/* use GConf to get defaults */
-	calibrate->priv->gconf_client = gconf_client_get_default ();
+	/* use GSettings to get defaults */
+	calibrate->priv->settings = g_settings_new (GCM_SETTINGS_SCHEMA);
 
 	/* coldplug, and watch for changes */
 	calibrate->priv->colorimeter_kind = gcm_colorimeter_get_kind (calibrate->priv->colorimeter);
@@ -1556,7 +1561,7 @@ gcm_calibrate_finalize (GObject *object)
 	g_object_unref (priv->colorimeter);
 	g_object_unref (priv->dmi);
 	g_object_unref (priv->calibrate_dialog);
-	g_object_unref (priv->gconf_client);
+	g_object_unref (priv->settings);
 
 	G_OBJECT_CLASS (gcm_calibrate_parent_class)->finalize (object);
 }
@@ -1574,45 +1579,3 @@ gcm_calibrate_new (void)
 	return GCM_CALIBRATE (calibrate);
 }
 
-/***************************************************************************
- ***                          MAKE CHECK TESTS                           ***
- ***************************************************************************/
-#ifdef EGG_TEST
-#include "egg-test.h"
-
-void
-gcm_calibrate_test (EggTest *test)
-{
-	GcmCalibrate *calibrate;
-	gboolean ret;
-	GError *error = NULL;
-	gchar *filename;
-
-	if (!egg_test_start (test, "GcmCalibrate"))
-		return;
-
-	/************************************************************/
-	egg_test_title (test, "get a calibrate object");
-	calibrate = gcm_calibrate_new ();
-	egg_test_assert (test, calibrate != NULL);
-
-	/************************************************************/
-	egg_test_title (test, "calibrate display manually");
-	filename = egg_test_get_data_file ("test.tif");
-	ret = gcm_calibrate_set_from_exif (GCM_CALIBRATE(calibrate), filename, &error);
-	if (!ret)
-		egg_test_failed (test, "error: %s", error->message);
-	else if (g_strcmp0 (gcm_calibrate_get_model_fallback (calibrate), "NIKON D60") != 0)
-		egg_test_failed (test, "got model: %s", gcm_calibrate_get_model_fallback (calibrate));
-	else if (g_strcmp0 (gcm_calibrate_get_manufacturer_fallback (calibrate), "NIKON CORPORATION") != 0)
-		egg_test_failed (test, "got manufacturer: %s", gcm_calibrate_get_manufacturer_fallback (calibrate));
-	else
-		egg_test_success (test, NULL);
-
-	g_object_unref (calibrate);
-	g_free (filename);
-
-	egg_test_end (test);
-}
-#endif
-
