@@ -26,7 +26,6 @@
 #include <libgnomeui/gnome-rr.h>
 #include <X11/extensions/Xrandr.h>
 #include <X11/extensions/xf86vmode.h>
-#include <gconf/gconf-client.h>
 #include <gdk/gdkx.h>
 
 #include "gcm-device-xrandr.h"
@@ -55,10 +54,11 @@ struct _GcmDeviceXrandrPrivate
 	guint				 gamma_size;
 	GcmEdid				*edid;
 	GcmDmi				*dmi;
-	GConfClient			*gconf_client;
+	GSettings			*settings;
 	GcmXserver			*xserver;
 	GcmScreen			*screen;
 	gboolean			 xrandr_fallback;
+	gboolean			 remove_atom;
 };
 
 enum {
@@ -432,6 +432,19 @@ out:
 	return ret;
 }
 
+/**
+ * gcm_device_xrandr_set_remove_atom:
+ *
+ * This is set to FALSE at login time when we are sure there are going to be
+ * no atoms previously set that have to be removed.
+ **/
+void
+gcm_device_xrandr_set_remove_atom (GcmDeviceXrandr *device_xrandr, gboolean remove_atom)
+{
+	g_return_if_fail (GCM_IS_DEVICE_XRANDR (device_xrandr));
+	device_xrandr->priv->remove_atom = remove_atom;
+}
+
 /**
  * gcm_device_xrandr_apply:
  *
@@ -478,15 +491,22 @@ gcm_device_xrandr_apply (GcmDevice *device, GError **error)
 		goto out;
 	}
 
-	/* if not saved, try to find default filename */
+	/* if not saved, try to find default profile */
 	saved = gcm_device_get_saved (device);
-	filename = gcm_device_get_profile_filename (device);
-	if (!saved && filename == NULL) {
-		filename_systemwide = g_strdup_printf ("%s/%s.icc", GCM_SYSTEM_PROFILES_DIR, id);
+	profile = gcm_device_get_default_profile (device);
+	if (profile != NULL)
+		g_object_ref (profile);
+	if (!saved && profile == NULL) {
+		filename_systemwide = g_strdup_printf ("%s/icc/%s.icc", GCM_SYSTEM_PROFILES_DIR, id);
 		ret = g_file_test (filename_systemwide, G_FILE_TEST_EXISTS);
 		if (ret) {
-			egg_error ("using systemwide %s as profile", filename_systemwide);
-			filename = g_strdup (filename_systemwide);
+			egg_debug ("using systemwide %s as profile", filename_systemwide);
+			profile = gcm_profile_default_new ();
+			file = g_file_new_for_path (filename_systemwide);
+			ret = gcm_profile_parse (profile, file, error);
+			g_object_unref (file);
+			if (!ret)
+				goto out;
 		}
 	}
 
@@ -508,19 +528,9 @@ gcm_device_xrandr_apply (GcmDevice *device, GError **error)
 		goto out;
 
 	/* only set the CLUT if we're not seting the atom */
-	use_global = gconf_client_get_bool (priv->gconf_client, GCM_SETTINGS_GLOBAL_DISPLAY_CORRECTION, NULL);
-	if (use_global && filename != NULL) {
-		/* create CLUT */
-		profile = gcm_profile_default_new ();
-		file = g_file_new_for_path (filename);
-		ret = gcm_profile_parse (profile, file, error);
-		g_object_unref (file);
-		if (!ret)
-			goto out;
-
-		/* create a CLUT from the profile */
+	use_global = g_settings_get_boolean (priv->settings, GCM_SETTINGS_GLOBAL_DISPLAY_CORRECTION);
+	if (use_global && profile != NULL)
 		clut = gcm_profile_generate_vcgt (profile, size);
-	}
 
 	/* create dummy CLUT if we failed */
 	if (clut == NULL) {
@@ -552,8 +562,12 @@ gcm_device_xrandr_apply (GcmDevice *device, GError **error)
 	leftmost_screen = (x == 0 && y == 0);
 
 	/* either remove the atoms or set them */
-	use_atom = gconf_client_get_bool (priv->gconf_client, GCM_SETTINGS_SET_ICC_PROFILE_ATOM, NULL);
-	if (!use_atom || filename == NULL) {
+	use_atom = g_settings_get_boolean (priv->settings, GCM_SETTINGS_SET_ICC_PROFILE_ATOM);
+	if (!use_atom || profile == NULL) {
+
+		/* at login we don't need to remove any previously set options */
+		if (!priv->remove_atom)
+			goto out;
 
 		/* remove the output atom if there's nothing to show */
 		ret = gcm_xserver_remove_output_profile (priv->xserver, output_name, error);
@@ -571,6 +585,7 @@ gcm_device_xrandr_apply (GcmDevice *device, GError **error)
 		}
 	} else {
 		/* set the per-output and per screen profile atoms */
+		filename = gcm_profile_get_filename (profile);
 		ret = gcm_xserver_set_output_profile (priv->xserver, output_name, filename, error);
 		if (!ret)
 			goto out;
@@ -695,10 +710,11 @@ gcm_device_xrandr_init (GcmDeviceXrandr *device_xrandr)
 	device_xrandr->priv->native_device = NULL;
 	device_xrandr->priv->eisa_id = NULL;
 	device_xrandr->priv->xrandr_fallback = FALSE;
+	device_xrandr->priv->remove_atom = TRUE;
 	device_xrandr->priv->gamma_size = 0;
 	device_xrandr->priv->edid = gcm_edid_new ();
 	device_xrandr->priv->dmi = gcm_dmi_new ();
-	device_xrandr->priv->gconf_client = gconf_client_get_default ();
+	device_xrandr->priv->settings = g_settings_new (GCM_SETTINGS_SCHEMA);
 	device_xrandr->priv->screen = gcm_screen_new ();
 	device_xrandr->priv->xserver = gcm_xserver_new ();
 }
@@ -716,7 +732,7 @@ gcm_device_xrandr_finalize (GObject *object)
 	g_free (priv->eisa_id);
 	g_object_unref (priv->edid);
 	g_object_unref (priv->dmi);
-	g_object_unref (priv->gconf_client);
+	g_object_unref (priv->settings);
 	g_object_unref (priv->screen);
 	g_object_unref (priv->xserver);
 
