@@ -592,164 +592,3 @@ gcm_edid_new (void)
 	return GCM_EDID (edid);
 }
 
-/***************************************************************************
- ***                          MAKE CHECK TESTS                           ***
- ***************************************************************************/
-#ifdef EGG_TEST
-#include "egg-test.h"
-
-typedef struct {
-	const gchar *monitor_name;
-	const gchar *vendor_name;
-	const gchar *serial_number;
-	const gchar *eisa_id;
-	const gchar *pnp_id;
-	guint width;
-	guint height;
-	gfloat gamma;
-} GcmEdidTestData;
-
-void
-gcm_edid_test_parse_edid_file (EggTest *test, GcmEdid *edid, const gchar *datafile, GcmEdidTestData *test_data)
-{
-	gchar *filename;
-	const gchar *monitor_name;
-	const gchar *vendor_name;
-	const gchar *serial_number;
-	const gchar *eisa_id;
-	const gchar *pnp_id;
-	gchar *data;
-	guint width;
-	guint height;
-	gfloat gamma;
-	gboolean ret;
-	GError *error = NULL;
-
-	/************************************************************/
-	egg_test_title (test, "get filename of data file");
-	filename = egg_test_get_data_file (datafile);
-	ret = g_file_get_contents (filename, &data, NULL, &error);
-	if (ret)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "failed to load: %s", error->message);
-
-	/************************************************************/
-	egg_test_title (test, "parse an example edid block");
-	ret = gcm_edid_parse (edid, data, &error);
-	if (ret)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "failed to parse: %s", error->message);
-
-	/************************************************************/
-	egg_test_title (test, "check monitor name for %s", datafile);
-	monitor_name = gcm_edid_get_monitor_name (edid);
-	if (g_strcmp0 (monitor_name, test_data->monitor_name) == 0)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "invalid value: %s, expecting: %s", monitor_name, test_data->monitor_name);
-
-	/************************************************************/
-	egg_test_title (test, "check vendor name for %s", datafile);
-	vendor_name = gcm_edid_get_vendor_name (edid);
-	if (g_strcmp0 (vendor_name, test_data->vendor_name) == 0)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "invalid value: %s, expecting: %s", vendor_name, test_data->vendor_name);
-
-	/************************************************************/
-	egg_test_title (test, "check serial number for %s", datafile);
-	serial_number = gcm_edid_get_serial_number (edid);
-	if (g_strcmp0 (serial_number, test_data->serial_number) == 0)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "invalid value: %s, expecting: %s", serial_number, test_data->serial_number);
-
-	/************************************************************/
-	egg_test_title (test, "check ascii string for %s", datafile);
-	eisa_id = gcm_edid_get_eisa_id (edid);
-	if (g_strcmp0 (eisa_id, test_data->eisa_id) == 0)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "invalid value: %s, expecting: %s", eisa_id, test_data->eisa_id);
-
-	/************************************************************/
-	egg_test_title (test, "check pnp id for %s", datafile);
-	pnp_id = gcm_edid_get_pnp_id (edid);
-	if (g_strcmp0 (pnp_id, test_data->pnp_id) == 0)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "invalid value: %s, expecting: %s", pnp_id, test_data->pnp_id);
-
-	/************************************************************/
-	egg_test_title (test, "check height for %s", datafile);
-	height = gcm_edid_get_height (edid);
-	if (height == test_data->height)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "invalid value: %i, expecting: %i", height, test_data->height);
-
-	/************************************************************/
-	egg_test_title (test, "check width for %s", datafile);
-	width = gcm_edid_get_width (edid);
-	if (width == test_data->width)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "invalid value: %i, expecting: %i", width, test_data->width);
-
-	/************************************************************/
-	egg_test_title (test, "check gamma for %s", datafile);
-	gamma = gcm_edid_get_gamma (edid);
-	if (gamma > (test_data->gamma - 0.01) && gamma < (test_data->gamma + 0.01))
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "invalid value: %f, expecting: %f", gamma, test_data->gamma);
-
-	g_free (filename);
-}
-
-void
-gcm_edid_test (EggTest *test)
-{
-	GcmEdid *edid;
-	gboolean ret;
-	GError *error = NULL;
-	GcmEdidTestData test_data;
-
-	if (!egg_test_start (test, "GcmEdid"))
-		return;
-
-	/************************************************************/
-	egg_test_title (test, "get a edid object");
-	edid = gcm_edid_new ();
-	egg_test_assert (test, edid != NULL);
-
-	/* LG 21" LCD panel */
-	test_data.monitor_name = "L225W";
-	test_data.vendor_name = "Goldstar Company Ltd";
-	test_data.serial_number = "34398";
-	test_data.eisa_id = NULL;
-	test_data.pnp_id = "GSM";
-	test_data.height = 30;
-	test_data.width = 47;
-	test_data.gamma = 2.2f;
-	gcm_edid_test_parse_edid_file (test, edid, "LG-L225W-External.bin", &test_data);
-
-	/* Lenovo T61 Intel Panel */
-	test_data.monitor_name = NULL;
-	test_data.vendor_name = "IBM France";
-	test_data.serial_number = NULL;
-	test_data.eisa_id = "LTN154P2-L05";
-	test_data.pnp_id = "IBM";
-	test_data.height = 21;
-	test_data.width = 33;
-	test_data.gamma = 2.2f;
-	gcm_edid_test_parse_edid_file (test, edid, "Lenovo-T61-Internal.bin", &test_data);
-
-	g_object_unref (edid);
-
-	egg_test_end (test);
-}
-#endif
-
