@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2009 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2009-2010 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -58,12 +58,14 @@ int
 main (int argc, char **argv)
 {
 	gboolean ret;
-	gchar *copyright = NULL;
-	gchar *description = NULL;
-	gchar *destination = NULL;
+	const gchar *copyright;
+	const gchar *description;
+	GFile *destination = NULL;
+	GFile *file = NULL;
 	gchar **files = NULL;
 	guint retval = 1;
 	GcmProfile *profile = NULL;
+	GcmColorspace colorspace;
 	GError *error = NULL;
 	GOptionContext *context;
 	GString *string = NULL;
@@ -109,7 +111,8 @@ main (int argc, char **argv)
 
 	/* load profile */
 	profile = gcm_profile_default_new ();
-	ret = gcm_profile_parse (profile, files[0], &error);
+	file = g_file_new_for_path (files[0]);
+	ret = gcm_profile_parse (profile, file, &error);
 	if (!ret) {
 		/* TRANSLATORS: could not read file */
 		dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, _("Failed to open ICC profile"));
@@ -123,13 +126,14 @@ main (int argc, char **argv)
 	}
 
 	/* get data */
+	description = gcm_profile_get_description (profile);
+	copyright = gcm_profile_get_copyright (profile);
+	colorspace = gcm_profile_get_colorspace (profile);
 	g_object_get (profile,
-		      "description", &description,
-		      "copyright", &copyright,
-		      "white-point", &white,
-		      "luminance-red", &red,
-		      "luminance-green", &green,
-		      "luminance-blue", &blue,
+		      "white", &white,
+		      "red", &red,
+		      "green", &green,
+		      "blue", &blue,
 		      NULL);
 
 	/* use CIE widget */
@@ -145,8 +149,8 @@ main (int argc, char **argv)
 		      NULL);
 
 	/* check file does't already exist */
-	destination = gcm_utils_get_profile_destination (files[0]);
-	ret = g_file_test (destination, G_FILE_TEST_EXISTS);
+	destination = gcm_utils_get_profile_destination (file);
+	ret = g_file_query_exists (destination, NULL);
 	if (ret) {
 		/* TRANSLATORS: color profile already been installed */
 		dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_INFO, GTK_BUTTONS_CLOSE, _("ICC profile already installed"));
@@ -186,6 +190,10 @@ main (int argc, char **argv)
 	/* add cie widget */
 	gcm_import_add_cie_widget (GTK_DIALOG(dialog), cie_widget);
 
+	/* only show the cie widget if we have RGB data */
+	if (colorspace != GCM_COLORSPACE_RGB)
+		gtk_widget_hide (cie_widget);
+
 	gtk_window_set_resizable (GTK_WINDOW (dialog), TRUE);
 	response = gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
@@ -194,8 +202,8 @@ main (int argc, char **argv)
 	if (response != GTK_RESPONSE_OK)
 		goto out;
 
-	/* copy icc file to ~/.color/icc */
-	ret = gcm_utils_mkdir_and_copy (files[0], destination, &error);
+	/* copy icc file to users profile path */
+	ret = gcm_utils_mkdir_and_copy (file, destination, &error);
 	if (!ret) {
 		/* TRANSLATORS: could not read file */
 		dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, _("Failed to copy file"));
@@ -215,6 +223,8 @@ main (int argc, char **argv)
 		goto out;
 	}
 out:
+	if (file != NULL)
+		g_object_unref (file);
 	if (white != NULL)
 		g_object_unref (white);
 	if (red != NULL)
@@ -227,9 +237,8 @@ out:
 		g_string_free (string, TRUE);
 	if (profile != NULL)
 		g_object_unref (profile);
-	g_free (destination);
-	g_free (description);
-	g_free (copyright);
+	if (destination != NULL)
+		g_object_unref (destination);
 	g_strfreev (files);
 	return retval;
 }
