@@ -55,12 +55,14 @@ struct _GcmProfilePrivate
 	GcmColorspace		 colorspace;
 	guint			 size;
 	gboolean		 has_vcgt;
+	gboolean		 can_delete;
 	gchar			*description;
 	gchar			*filename;
 	gchar			*copyright;
 	gchar			*manufacturer;
 	gchar			*model;
 	gchar			*datetime;
+	gchar			*checksum;
 	GcmXyz			*white;
 	GcmXyz			*black;
 	GcmXyz			*red;
@@ -75,12 +77,14 @@ enum {
 	PROP_MANUFACTURER,
 	PROP_MODEL,
 	PROP_DATETIME,
+	PROP_CHECKSUM,
 	PROP_DESCRIPTION,
 	PROP_FILENAME,
 	PROP_KIND,
 	PROP_COLORSPACE,
 	PROP_SIZE,
 	PROP_HAS_VCGT,
+	PROP_CAN_DELETE,
 	PROP_WHITE,
 	PROP_BLACK,
 	PROP_RED,
@@ -131,7 +135,6 @@ gcm_profile_set_description (GcmProfile *profile, const gchar *description)
 	g_object_notify (G_OBJECT (profile), "description");
 }
 
-
 /**
  * gcm_profile_get_filename:
  **/
@@ -195,7 +198,6 @@ gcm_profile_set_filename (GcmProfile *profile, const gchar *filename)
 	g_object_notify (G_OBJECT (profile), "filename");
 }
 
-
 /**
  * gcm_profile_get_copyright:
  **/
@@ -223,7 +225,6 @@ gcm_profile_set_copyright (GcmProfile *profile, const gchar *copyright)
 	g_object_notify (G_OBJECT (profile), "copyright");
 }
 
-
 /**
  * gcm_profile_get_model:
  **/
@@ -278,7 +279,6 @@ gcm_profile_set_manufacturer (GcmProfile *profile, const gchar *manufacturer)
 	g_object_notify (G_OBJECT (profile), "manufacturer");
 }
 
-
 /**
  * gcm_profile_get_datetime:
  **/
@@ -304,6 +304,30 @@ gcm_profile_set_datetime (GcmProfile *profile, const gchar *datetime)
 	g_object_notify (G_OBJECT (profile), "datetime");
 }
 
+/**
+ * gcm_profile_get_checksum:
+ **/
+const gchar *
+gcm_profile_get_checksum (GcmProfile *profile)
+{
+	g_return_val_if_fail (GCM_IS_PROFILE (profile), NULL);
+	return profile->priv->checksum;
+}
+
+/**
+ * gcm_profile_set_checksum:
+ **/
+static void
+gcm_profile_set_checksum (GcmProfile *profile, const gchar *checksum)
+{
+	GcmProfilePrivate *priv = profile->priv;
+
+	g_return_if_fail (GCM_IS_PROFILE (profile));
+
+	g_free (priv->checksum);
+	priv->checksum = g_strdup (checksum);
+	g_object_notify (G_OBJECT (profile), "checksum");
+}
 
 /**
  * gcm_profile_get_size:
@@ -326,7 +350,6 @@ gcm_profile_set_size (GcmProfile *profile, guint size)
 	g_object_notify (G_OBJECT (profile), "size");
 }
 
-
 /**
  * gcm_profile_get_kind:
  **/
@@ -348,7 +371,6 @@ gcm_profile_set_kind (GcmProfile *profile, GcmProfileKind kind)
 	g_object_notify (G_OBJECT (profile), "kind");
 }
 
-
 /**
  * gcm_profile_get_colorspace:
  **/
@@ -370,7 +392,6 @@ gcm_profile_set_colorspace (GcmProfile *profile, GcmColorspace colorspace)
 	g_object_notify (G_OBJECT (profile), "colorspace");
 }
 
-
 /**
  * gcm_profile_get_has_vcgt:
  **/
@@ -392,6 +413,16 @@ gcm_profile_set_has_vcgt (GcmProfile *profile, gboolean has_vcgt)
 	g_object_notify (G_OBJECT (profile), "has_vcgt");
 }
 
+/**
+ * gcm_profile_get_can_delete:
+ **/
+gboolean
+gcm_profile_get_can_delete (GcmProfile *profile)
+{
+	g_return_val_if_fail (GCM_IS_PROFILE (profile), FALSE);
+	return profile->priv->can_delete;
+}
+
 /**
  * gcm_profile_parse_data:
  **/
@@ -399,6 +430,7 @@ gboolean
 gcm_profile_parse_data (GcmProfile *profile, const guint8 *data, gsize length, GError **error)
 {
 	gboolean ret = FALSE;
+	gchar *checksum = NULL;
 	GcmProfilePrivate *priv = profile->priv;
 	GcmProfileClass *klass = GCM_PROFILE_GET_CLASS (profile);
 
@@ -413,7 +445,14 @@ gcm_profile_parse_data (GcmProfile *profile, const guint8 *data, gsize length, G
 
 	/* proxy */
 	ret = klass->parse_data (profile, data, length, error);
+	if (!ret)
+		goto out;
+
+	/* generate and set checksum */
+	checksum = g_compute_checksum_for_data (G_CHECKSUM_MD5, (const guchar *) data, length);
+	gcm_profile_set_checksum (profile, checksum);
 out:
+	g_free (checksum);
 	return ret;
 }
 
@@ -424,14 +463,22 @@ gboolean
 gcm_profile_parse (GcmProfile *profile, GFile *file, GError **error)
 {
 	gchar *data = NULL;
-	gboolean ret;
+	gboolean ret = FALSE;
 	gsize length;
 	gchar *filename = NULL;
 	GError *error_local = NULL;
+	GFileInfo *info;
 
 	g_return_val_if_fail (GCM_IS_PROFILE (profile), FALSE);
 	g_return_val_if_fail (file != NULL, FALSE);
 
+	/* find out if the user could delete this profile */
+	info = g_file_query_info (file, G_FILE_ATTRIBUTE_ACCESS_CAN_DELETE,
+				  G_FILE_QUERY_INFO_NONE, NULL, error);
+	if (info == NULL)
+		goto out;
+	profile->priv->can_delete = g_file_info_get_attribute_boolean (info, G_FILE_ATTRIBUTE_ACCESS_CAN_DELETE);
+
 	/* load files */
 	ret = g_file_load_contents (file, NULL, &data, &length, NULL, &error_local);
 	if (!ret) {
@@ -449,6 +496,8 @@ gcm_profile_parse (GcmProfile *profile, GFile *file, GError **error)
 	filename = g_file_get_path (file);
 	gcm_profile_set_filename (profile, filename);
 out:
+	if (info != NULL)
+		g_object_unref (info);
 	g_free (filename);
 	g_free (data);
 	return ret;
@@ -565,6 +614,9 @@ gcm_profile_get_property (GObject *object, guint prop_id, GValue *value, GParamS
 	case PROP_DATETIME:
 		g_value_set_string (value, priv->datetime);
 		break;
+	case PROP_CHECKSUM:
+		g_value_set_string (value, priv->checksum);
+		break;
 	case PROP_DESCRIPTION:
 		g_value_set_string (value, priv->description);
 		break;
@@ -583,6 +635,9 @@ gcm_profile_get_property (GObject *object, guint prop_id, GValue *value, GParamS
 	case PROP_HAS_VCGT:
 		g_value_set_boolean (value, priv->has_vcgt);
 		break;
+	case PROP_CAN_DELETE:
+		g_value_set_boolean (value, priv->can_delete);
+		break;
 	case PROP_WHITE:
 		g_value_set_object (value, priv->white);
 		break;
@@ -709,6 +764,14 @@ gcm_profile_class_init (GcmProfileClass *klass)
 				     G_PARAM_READWRITE);
 	g_object_class_install_property (object_class, PROP_DATETIME, pspec);
 
+	/**
+	 * GcmProfile:checksum:
+	 */
+	pspec = g_param_spec_string ("checksum", NULL, NULL,
+				     NULL,
+				     G_PARAM_READABLE);
+	g_object_class_install_property (object_class, PROP_CHECKSUM, pspec);
+
 	/**
 	 * GcmProfile:description:
 	 */
@@ -757,6 +820,14 @@ gcm_profile_class_init (GcmProfileClass *klass)
 				      G_PARAM_READWRITE);
 	g_object_class_install_property (object_class, PROP_HAS_VCGT, pspec);
 
+	/**
+	 * GcmProfile:can-delete:
+	 */
+	pspec = g_param_spec_boolean ("can-delete", NULL, NULL,
+				      FALSE,
+				      G_PARAM_READABLE);
+	g_object_class_install_property (object_class, PROP_CAN_DELETE, pspec);
+
 	/**
 	 * GcmProfile:white:
 	 */
@@ -807,6 +878,7 @@ static void
 gcm_profile_init (GcmProfile *profile)
 {
 	profile->priv = GCM_PROFILE_GET_PRIVATE (profile);
+	profile->priv->can_delete = FALSE;
 	profile->priv->monitor = NULL;
 	profile->priv->kind = GCM_PROFILE_KIND_UNKNOWN;
 	profile->priv->colorspace = GCM_COLORSPACE_UNKNOWN;
@@ -832,6 +904,7 @@ gcm_profile_finalize (GObject *object)
 	g_free (priv->manufacturer);
 	g_free (priv->model);
 	g_free (priv->datetime);
+	g_free (priv->checksum);
 	g_object_unref (priv->white);
 	g_object_unref (priv->black);
 	g_object_unref (priv->red);
@@ -869,169 +942,3 @@ gcm_profile_default_new (void)
 	return profile;
 }
 
-/***************************************************************************
- ***                          MAKE CHECK TESTS                           ***
- ***************************************************************************/
-#ifdef EGG_TEST
-#include <math.h>
-#include "egg-test.h"
-
-typedef struct {
-	const gchar *copyright;
-	const gchar *manufacturer;
-	const gchar *model;
-	const gchar *datetime;
-	const gchar *description;
-	GcmProfileKind kind;
-	GcmColorspace colorspace;
-	gfloat luminance;
-} GcmProfileTestData;
-
-void
-gcm_profile_test_parse_file (EggTest *test, const guint8 *datafile, GcmProfileTestData *test_data)
-{
-	gchar *filename = NULL;
-	const gchar *copyright;
-	const gchar *manufacturer;
-	const gchar *model;
-	const gchar *datetime;
-	const gchar *description;
-	const gchar *eisa_id;
-	const gchar *pnp_id;
-	guint width;
-	guint kind;
-	guint colorspace;
-	gfloat gamma;
-	gboolean ret;
-	GError *error = NULL;
-	GcmProfile *profile_lcms1;
-	GcmXyz *xyz;
-	gfloat luminance;
-	GFile *file;
-
-	/************************************************************/
-	egg_test_title (test, "get a profile_lcms1 object");
-	profile_lcms1 = GCM_PROFILE(gcm_profile_lcms1_new ());
-	egg_test_assert (test, profile_lcms1 != NULL);
-
-	/************************************************************/
-	egg_test_title (test, "get filename of data file");
-	filename = egg_test_get_data_file (datafile);
-	egg_test_assert (test, (filename != NULL));
-
-	/************************************************************/
-	egg_test_title (test, "load ICC file");
-	file = g_file_new_for_path (filename);
-	ret = gcm_profile_parse (profile_lcms1, file, &error);
-	if (ret)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "failed to parse: %s", error->message);
-	g_object_unref (file);
-
-	/************************************************************/
-	egg_test_title (test, "check copyright for %s", datafile);
-	copyright = gcm_profile_get_copyright (profile_lcms1);
-	if (g_strcmp0 (copyright, test_data->copyright) == 0)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "invalid value: %s, expecting: %s", copyright, test_data->copyright);
-
-	/************************************************************/
-	egg_test_title (test, "check manufacturer for %s", datafile);
-	manufacturer = gcm_profile_get_manufacturer (profile_lcms1);
-	if (g_strcmp0 (manufacturer, test_data->manufacturer) == 0)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "invalid value: %s, expecting: %s", manufacturer, test_data->manufacturer);
-
-	/************************************************************/
-	egg_test_title (test, "check model for %s", datafile);
-	model = gcm_profile_get_model (profile_lcms1);
-	if (g_strcmp0 (model, test_data->model) == 0)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "invalid value: %s, expecting: %s", model, test_data->model);
-
-	/************************************************************/
-	egg_test_title (test, "check datetime for %s", datafile);
-	datetime = gcm_profile_get_datetime (profile_lcms1);
-	if (g_strcmp0 (datetime, test_data->datetime) == 0)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "invalid value: %s, expecting: %s", datetime, test_data->datetime);
-
-	/************************************************************/
-	egg_test_title (test, "check description for %s", datafile);
-	description = gcm_profile_get_description (profile_lcms1);
-	if (g_strcmp0 (description, test_data->description) == 0)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "invalid value: %s, expecting: %s", description, test_data->description);
-
-	/************************************************************/
-	egg_test_title (test, "check kind for %s", datafile);
-	kind = gcm_profile_get_kind (profile_lcms1);
-	if (kind == test_data->kind)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "invalid value: %i, expecting: %i", kind, test_data->kind);
-
-	/************************************************************/
-	egg_test_title (test, "check colorspace for %s", datafile);
-	colorspace = gcm_profile_get_colorspace (profile_lcms1);
-	if (colorspace == test_data->colorspace)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "invalid value: %i, expecting: %i", colorspace, test_data->colorspace);
-
-	/************************************************************/
-	egg_test_title (test, "check luminance red %s", datafile);
-	g_object_get (profile_lcms1,
-		      "red", &xyz,
-		      NULL);
-	luminance = gcm_xyz_get_x (xyz);
-	if (fabs (luminance - test_data->luminance) < 0.001)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "invalid value: %f, expecting: %f", luminance, test_data->luminance);
-
-	g_object_unref (xyz);
-	g_object_unref (profile_lcms1);
-	g_free (filename);
-}
-
-void
-gcm_profile_test (EggTest *test)
-{
-	GcmProfileTestData test_data;
-
-	if (!egg_test_start (test, "GcmProfile"))
-		return;
-
-	/* bluish test */
-	test_data.copyright = "Copyright (c) 1998 Hewlett-Packard Company";
-	test_data.manufacturer = "IEC http://www.iec.ch";
-	test_data.model = "IEC 61966-2.1 Default RGB colour space - sRGB";
-	test_data.description = "Blueish Test";
-	test_data.kind = GCM_PROFILE_KIND_DISPLAY_DEVICE;
-	test_data.colorspace = GCM_COLORSPACE_RGB;
-	test_data.luminance = 0.648454;
-	test_data.datetime = "February  9 1998, 06:49:00 AM";
-	gcm_profile_test_parse_file (test, "bluish.icc", &test_data);
-
-	/* Adobe test */
-	test_data.copyright = "Copyright (c) 1998 Hewlett-Packard Company Modified using Adobe Gamma";
-	test_data.manufacturer = "IEC http://www.iec.ch";
-	test_data.model = "IEC 61966-2.1 Default RGB colour space - sRGB";
-	test_data.description = "ADOBEGAMMA-Test";
-	test_data.kind = GCM_PROFILE_KIND_DISPLAY_DEVICE;
-	test_data.colorspace = GCM_COLORSPACE_RGB;
-	test_data.luminance = 0.648446;
-	test_data.datetime = "August 16 2005, 09:49:54 PM";
-	gcm_profile_test_parse_file (test, "AdobeGammaTest.icm", &test_data);
-
-	egg_test_end (test);
-}
-#endif
-
