@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2006-2009 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2006-2010 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -392,81 +392,3 @@ gcm_trc_widget_new (void)
 	return g_object_new (GCM_TYPE_TRC_WIDGET, NULL);
 }
 
-/***************************************************************************
- ***                          MAKE CHECK TESTS                           ***
- ***************************************************************************/
-#ifdef EGG_TEST
-#include "egg-test.h"
-
-void
-gcm_trc_widget_test (EggTest *test)
-{
-	GtkWidget *widget;
-	GtkWidget *image;
-	GtkWidget *dialog;
-	GtkWidget *vbox;
-	gboolean ret;
-	GError *error = NULL;
-	GcmClut *clut;
-	GcmProfile *profile;
-	gint response;
-	gchar *filename_profile;
-	gchar *filename_image;
-	GcmClutData *data;
-	GFile *file;
-
-	if (!egg_test_start (test, "GcmTrcWidget"))
-		return;
-
-	/************************************************************/
-	egg_test_title (test, "get a TRC widget object");
-	widget = gcm_trc_widget_new ();
-	egg_test_assert (test, widget != NULL);
-
-	/************************************************************/
-	egg_test_title (test, "get filename of image file");
-	filename_image = egg_test_get_data_file ("trc-widget.png");
-	egg_test_assert (test, (filename_image != NULL));
-
-	/************************************************************/
-	egg_test_title (test, "get filename of data file");
-	filename_profile = egg_test_get_data_file ("AdobeGammaTest.icm");
-	egg_test_assert (test, (filename_profile != NULL));
-
-	profile = gcm_profile_default_new ();
-	file = g_file_new_for_path (filename_profile);
-	gcm_profile_parse (profile, file, NULL);
-	clut = gcm_profile_generate_vcgt (profile, 256);
-	g_object_set (widget,
-		      "clut", clut,
-		      NULL);
-	g_object_unref (file);
-
-	/* show in a dialog as an example */
-	dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, "Does TRC widget match\nthe picture below?");
-	image = gtk_image_new_from_file (filename_image);
-	vbox = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
-	gtk_box_pack_end (GTK_BOX(vbox), widget, TRUE, TRUE, 12);
-	gtk_box_pack_end (GTK_BOX(vbox), image, TRUE, TRUE, 12);
-	gtk_widget_set_size_request (widget, 300, 300);
-	gtk_window_set_resizable (GTK_WINDOW (dialog), TRUE);
-	gtk_widget_show (widget);
-	gtk_widget_show (image);
-
-	response = gtk_dialog_run (GTK_DIALOG (dialog));
-
-	/************************************************************/
-	egg_test_title (test, "plotted as expected?");
-	egg_test_assert (test, (response == GTK_RESPONSE_YES));
-
-	gtk_widget_destroy (dialog);
-
-	g_object_unref (clut);
-	g_object_unref (profile);
-	g_free (filename_profile);
-	g_free (filename_image);
-
-	egg_test_end (test);
-}
-#endif
-
