@@ -23,13 +23,17 @@
 
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include <dbus/dbus-glib.h>
 #include <gdk/gdkx.h>
 
 #include "gcm-utils.h"
 
 #include "egg-debug.h"
 
+#define PK_DBUS_SERVICE					"org.freedesktop.PackageKit"
+#define PK_DBUS_PATH					"/org/freedesktop/PackageKit"
+#define PK_DBUS_INTERFACE_QUERY				"org.freedesktop.PackageKit.Query"
+#define PK_DBUS_INTERFACE_MODIFY			"org.freedesktop.PackageKit.Modify"
+
 /**
  * gcm_utils_linkify:
  **/
@@ -130,10 +134,12 @@ out:
 gboolean
 gcm_utils_install_package (const gchar *package_name, GtkWindow *window)
 {
-	DBusGConnection *connection;
-	DBusGProxy *proxy;
+	GDBusConnection *connection;
+	GVariant *args = NULL;
+	GVariant *response = NULL;
+	GVariantBuilder *builder = NULL;
 	GError *error = NULL;
-	gboolean ret;
+	gboolean ret = FALSE;
 	guint32 xid = 0;
 	gchar **packages = NULL;
 
@@ -141,7 +147,7 @@ gcm_utils_install_package (const gchar *package_name, GtkWindow *window)
 
 #ifndef GCM_USE_PACKAGEKIT
 	egg_warning ("cannot install %s: this package was not compiled with --enable-packagekit", package_name);
-	return FALSE;
+	goto out;
 #endif
 
 	/* get xid of this window */
@@ -152,30 +158,47 @@ gcm_utils_install_package (const gchar *package_name, GtkWindow *window)
 	packages = g_strsplit (package_name, "|", 1);
 
 	/* get a session bus connection */
-	connection = dbus_g_bus_get (DBUS_BUS_SESSION, NULL);
-
-	/* connect to PackageKit */
-	proxy = dbus_g_proxy_new_for_name (connection,
-					   "org.freedesktop.PackageKit",
-					   "/org/freedesktop/PackageKit",
-					   "org.freedesktop.PackageKit.Modify");
-
-	/* set timeout */
-	dbus_g_proxy_set_default_timeout (proxy, G_MAXINT);
-
-	/* execute sync method */
-	ret = dbus_g_proxy_call (proxy, "InstallPackageNames", &error,
-				 G_TYPE_UINT, xid,
-				 G_TYPE_STRV, packages,
-				 G_TYPE_STRING, "hide-confirm-search,hide-finished",
-				 G_TYPE_INVALID, G_TYPE_INVALID);
-	if (!ret) {
-		egg_warning ("failed to install package: %s", error->message);
+	connection = g_bus_get_sync (G_BUS_TYPE_SESSION, NULL, &error);
+	if (connection == NULL) {
+		/* TRANSLATORS: no DBus session bus */
+		g_print ("%s %s\n", _("Failed to connect to session bus:"), error->message);
 		g_error_free (error);
 		goto out;
 	}
+
+	/* create arguments */
+	builder = g_variant_builder_new (G_VARIANT_TYPE ("(uass)"));
+	g_variant_builder_add_value (builder, g_variant_new_uint32 (xid));
+	g_variant_builder_add_value (builder, g_variant_new_strv ((const gchar * const *)packages, -1));
+	g_variant_builder_add_value (builder, g_variant_new_string ("hide-confirm-search,hide-finished"));
+	args = g_variant_builder_end (builder);
+
+	/* execute sync method */
+	response = g_dbus_connection_call_sync (connection,
+						PK_DBUS_SERVICE,
+						PK_DBUS_PATH,
+						PK_DBUS_INTERFACE_MODIFY,
+						"InstallPackageNames",
+						args,
+						G_VARIANT_TYPE ("(b)"),
+						G_DBUS_CALL_FLAGS_NONE,
+						G_MAXINT, NULL, &error);
+	if (response == NULL) {
+		/* TRANSLATORS: the DBus method failed */
+		egg_warning ("%s %s\n", _("The request failed:"), error->message);
+		g_error_free (error);
+		goto out;
+	}
+
+	/* success */
+	ret = TRUE;
 out:
-	g_object_unref (proxy);
+	if (builder != NULL)
+		g_variant_builder_unref (builder);
+	if (args != NULL)
+		g_variant_unref (args);
+	if (response != NULL)
+		g_variant_unref (response);
 	g_strfreev (packages);
 	return ret;
 }
@@ -186,10 +209,10 @@ out:
 gboolean
 gcm_utils_is_package_installed (const gchar *package_name)
 {
-	DBusGConnection *connection;
-	DBusGProxy *proxy;
+	GDBusConnection *connection;
+	GVariant *args = NULL;
+	GVariant *response = NULL;
 	GError *error = NULL;
-	gboolean ret;
 	gboolean installed = TRUE;
 
 	g_return_val_if_fail (package_name != NULL, FALSE);
@@ -200,31 +223,39 @@ gcm_utils_is_package_installed (const gchar *package_name)
 #endif
 
 	/* get a session bus connection */
-	connection = dbus_g_bus_get (DBUS_BUS_SESSION, NULL);
-
-	/* connect to PackageKit */
-	proxy = dbus_g_proxy_new_for_name (connection,
-					   "org.freedesktop.PackageKit",
-					   "/org/freedesktop/PackageKit",
-					   "org.freedesktop.PackageKit.Query");
-
-	/* set timeout */
-	dbus_g_proxy_set_default_timeout (proxy, G_MAXINT);
-
-	/* execute sync method */
-	ret = dbus_g_proxy_call (proxy, "IsInstalled", &error,
-				 G_TYPE_STRING, package_name,
-				 G_TYPE_STRING, "timeout=5",
-				 G_TYPE_INVALID,
-				 G_TYPE_BOOLEAN, &installed,
-				 G_TYPE_INVALID);
-	if (!ret) {
-		egg_warning ("failed to get installed status: %s", error->message);
+	connection = g_bus_get_sync (G_BUS_TYPE_SESSION, NULL, &error);
+	if (connection == NULL) {
+		/* TRANSLATORS: no DBus session bus */
+		g_print ("%s %s\n", _("Failed to connect to session bus:"), error->message);
 		g_error_free (error);
 		goto out;
 	}
+
+	/* execute sync method */
+	args = g_variant_new ("(ss)", package_name, "timeout=5");
+	response = g_dbus_connection_call_sync (connection,
+						PK_DBUS_SERVICE,
+						PK_DBUS_PATH,
+						PK_DBUS_INTERFACE_QUERY,
+						"IsInstalled",
+						args,
+						G_VARIANT_TYPE ("(b)"),
+						G_DBUS_CALL_FLAGS_NONE,
+						G_MAXINT, NULL, &error);
+	if (response == NULL) {
+		/* TRANSLATORS: the DBus method failed */
+		egg_warning ("%s %s\n", _("The request failed:"), error->message);
+		g_error_free (error);
+		goto out;
+	}
+
+	/* get value */
+	g_variant_get (response, "(b)", &installed);
 out:
-	g_object_unref (proxy);
+	if (args != NULL)
+		g_variant_unref (args);
+	if (response != NULL)
+		g_variant_unref (response);
 	return installed;
 }
 
@@ -321,9 +352,9 @@ gcm_utils_mkdir_for_filename (const gchar *filename, GError **error)
 	GFile *parent_dir = NULL;
 
 	/* get a file from the URI / path */
-	file = g_file_new_for_uri (filename);
+	file = g_file_new_for_path (filename);
 	if (file == NULL)
-		file = g_file_new_for_path (filename);
+		file = g_file_new_for_uri (filename);
 	if (file == NULL) {
 		g_set_error (error, 1, 0, "could not resolve file for %s", filename);
 		goto out;
@@ -396,7 +427,7 @@ gcm_utils_get_profile_destination (GFile *file)
 
 	/* get destination filename for this source file */
 	basename = g_file_get_basename (file);
-	destination = g_build_filename (g_get_home_dir (), GCM_PROFILE_PATH, basename, NULL);
+	destination = g_build_filename (g_get_user_data_dir (), "icc", basename, NULL);
 	dest = g_file_new_for_path (destination);
 
 	g_free (basename);
@@ -515,13 +546,14 @@ gcm_utils_get_default_config_location (void)
 {
 	gchar *filename;
 
-#ifdef EGG_TEST
-	filename = g_strdup ("/tmp/device-profiles.conf");
-#else
-	/* create default path */
-	filename = g_build_filename (g_get_user_config_dir (), "gnome-color-manager", "device-profiles.conf", NULL);
-#endif
+	if (g_getenv ("GCM_TEST") != NULL) {
+		filename = g_strdup ("/tmp/device-profiles.conf");
+		goto out;
+	}
 
+	/* create default path */
+	filename = g_build_filename (g_get_user_config_dir (), "color", "device-profiles.conf", NULL);
+out:
 	return filename;
 }
 
@@ -576,7 +608,7 @@ gcm_intent_to_localized_text (GcmIntent intent)
 	}
 	if (intent == GCM_INTENT_RELATIVE_COLORMETRIC) {
 		/* TRANSLATORS: rendering intent: you probably want to google this */
-		return _("Relative colormetric");
+		return _("Relative");
 	}
 	if (intent == GCM_INTENT_SATURATION) {
 		/* TRANSLATORS: rendering intent: you probably want to google this */
@@ -584,136 +616,33 @@ gcm_intent_to_localized_text (GcmIntent intent)
 	}
 	if (intent == GCM_INTENT_ABSOLUTE_COLORMETRIC) {
 		/* TRANSLATORS: rendering intent: you probably want to google this */
-		return _("Absolute colormetric");
+		return _("Absolute");
 	}
 	return "unknown";
 }
 
-/***************************************************************************
- ***                          MAKE CHECK TESTS                           ***
- ***************************************************************************/
-#ifdef EGG_TEST
-#include "egg-test.h"
-
-void
-gcm_utils_test (EggTest *test)
+/**
+ * gcm_intent_to_localized_description:
+ **/
+const gchar *
+gcm_intent_to_localized_description (GcmIntent intent)
 {
-	gboolean ret;
-	GError *error = NULL;
-	GPtrArray *array;
-	gchar *text;
-	gchar *filename;
-	GcmProfileKind profile_kind;
-	GcmDeviceKind device_kind;
-	GFile *file;
-	GFile *dest;
-
-	if (!egg_test_start (test, "GcmUtils"))
-		return;
-
-	/************************************************************/
-	egg_test_title (test, "Linkify text");
-	text = gcm_utils_linkify ("http://www.dave.org is text http://www.hughsie.com that needs to be linked to http://www.bbc.co.uk really");
-	if (g_strcmp0 (text, "<a href=\"http://www.dave.org\">http://www.dave.org</a> is text "
-			     "<a href=\"http://www.hughsie.com\">http://www.hughsie.com</a> that needs to be linked to "
-			     "<a href=\"http://www.bbc.co.uk\">http://www.bbc.co.uk</a> really") == 0)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "failed to linkify text: %s", text);
-	g_free (text);
-
-	/************************************************************/
-	egg_test_title (test, "get filename of data file");
-	file = g_file_new_for_path ("dave.icc");
-	dest = gcm_utils_get_profile_destination (file);
-	filename = g_file_get_path (dest);
-	if (g_str_has_suffix (filename, "/.color/icc/dave.icc"))
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "failed to get filename: %s", filename);
-	g_free (filename);
-	g_object_unref (file);
-	g_object_unref (dest);
-
-	/************************************************************/
-	egg_test_title (test, "check is icc profile");
-	filename = egg_test_get_data_file ("bluish.icc");
-	file = g_file_new_for_path (filename);
-	ret = gcm_utils_is_icc_profile (file);
-	egg_test_assert (test, ret);
-	g_object_unref (file);
-	g_free (filename);
-
-	/************************************************************/
-	egg_test_title (test, "detect LVDS panels");
-	ret = gcm_utils_output_is_lcd_internal ("LVDS1");
-	egg_test_assert (test, ret);
-
-	/************************************************************/
-	egg_test_title (test, "detect external panels");
-	ret = gcm_utils_output_is_lcd_internal ("DVI1");
-	egg_test_assert (test, !ret);
-
-	/************************************************************/
-	egg_test_title (test, "detect LCD panels");
-	ret = gcm_utils_output_is_lcd ("LVDS1");
-	egg_test_assert (test, ret);
-
-	/************************************************************/
-	egg_test_title (test, "detect LCD panels (2)");
-	ret = gcm_utils_output_is_lcd ("DVI1");
-	egg_test_assert (test, ret);
-
-	/************************************************************/
-	egg_test_title (test, "Make sensible id");
-	filename = g_strdup ("Hello\n\rWorld!");
-	gcm_utils_alphanum_lcase (filename);
-	if (g_strcmp0 (filename, "hello__world_") == 0)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "failed to get filename: %s", filename);
-	g_free (filename);
-
-	/************************************************************/
-	egg_test_title (test, "Make sensible filename");
-	filename = g_strdup ("Hel lo\n\rWo-(r)ld!");
-	gcm_utils_ensure_sensible_filename (filename);
-	if (g_strcmp0 (filename, "Hel lo__Wo-(r)ld_") == 0)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "failed to get filename: %s", filename);
-	g_free (filename);
-
-	/************************************************************/
-	egg_test_title (test, "check strip printable");
-	text = g_strdup ("1\r34 67_90");
-	gcm_utils_ensure_printable (text);
-	if (g_strcmp0 (text, "134 67 90") == 0)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "invalid value: %s", text);
-	g_free (text);
-
-	/************************************************************/
-	egg_test_title (test, "get default config location (when in make check)");
-	filename = gcm_utils_get_default_config_location ();
-	if (g_strcmp0 (filename, "/tmp/device-profiles.conf") == 0)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "failed to get correct config location: %s", filename);
-	g_free (filename);
-
-	/************************************************************/
-	egg_test_title (test, "convert valid device kind to profile kind");
-	profile_kind = gcm_utils_device_kind_to_profile_kind (GCM_DEVICE_KIND_SCANNER);
-	egg_test_assert (test, (profile_kind == GCM_PROFILE_KIND_INPUT_DEVICE));
-
-	/************************************************************/
-	egg_test_title (test, "convert invalid device kind to profile kind");
-	profile_kind = gcm_utils_device_kind_to_profile_kind (GCM_DEVICE_KIND_UNKNOWN);
-	egg_test_assert (test, (profile_kind == GCM_PROFILE_KIND_UNKNOWN));
-
-	egg_test_end (test);
+	if (intent == GCM_INTENT_PERCEPTUAL) {
+		/* TRANSLATORS: rendering intent: you probably want to google this */
+		return _("High quality photography");
+	}
+	if (intent == GCM_INTENT_RELATIVE_COLORMETRIC) {
+		/* TRANSLATORS: rendering intent: you probably want to google this */
+		return _("Precise color matching");
+	}
+	if (intent == GCM_INTENT_SATURATION) {
+		/* TRANSLATORS: rendering intent: you probably want to google this */
+		return _("Graphs and presentations");
+	}
+	if (intent == GCM_INTENT_ABSOLUTE_COLORMETRIC) {
+		/* TRANSLATORS: rendering intent: you probably want to google this */
+		return _("Proofing devices");
+	}
+	return "unknown";
 }
-#endif
 
