@@ -29,23 +29,31 @@
 #include "gcm-profile.h"
 #include "gcm-enum.h"
 
-#define GCM_STOCK_ICON				"gnome-color-manager"
-#define GCM_PROFILE_PATH			"/.color/icc"
+#define GCM_STOCK_ICON					"gnome-color-manager"
+#define GCM_DBUS_SERVICE				"org.gnome.ColorManager"
+#define GCM_DBUS_INTERFACE				"org.gnome.ColorManager"
+#define GCM_DBUS_PATH					"/org/gnome/ColorManager"
 
-#define GCM_SETTINGS_DIR			"/apps/gnome-color-manager"
-#define GCM_SETTINGS_DEFAULT_GAMMA		"/apps/gnome-color-manager/default_gamma"
-#define GCM_SETTINGS_GLOBAL_DISPLAY_CORRECTION	"/apps/gnome-color-manager/global_display_correction"
-#define GCM_SETTINGS_SET_ICC_PROFILE_ATOM	"/apps/gnome-color-manager/set_icc_profile_atom"
-#define GCM_SETTINGS_RENDERING_INTENT_DISPLAY	"/apps/gnome-color-manager/rendering_intent_display"
-#define GCM_SETTINGS_RENDERING_INTENT_SOFTPROOF	"/apps/gnome-color-manager/rendering_intent_softproof"
-#define GCM_SETTINGS_COLORSPACE_RGB		"/apps/gnome-color-manager/colorspace_rgb"
-#define GCM_SETTINGS_COLORSPACE_CMYK		"/apps/gnome-color-manager/colorspace_cmyk"
-#define GCM_SETTINGS_USE_PROFILES_FROM_VOLUMES	"/apps/gnome-color-manager/use_profiles_from_volumes"
-#define GCM_SETTINGS_CALIBRATION_LENGTH		"/apps/gnome-color-manager/calibration_length"
-#define GCM_SETTINGS_SHOW_FINE_TUNING		"/apps/gnome-color-manager/show_fine_tuning"
+#define GCM_SETTINGS_SCHEMA				"org.gnome.color-manager"
+#define GCM_SETTINGS_DEFAULT_GAMMA			"default-gamma"
+#define GCM_SETTINGS_GLOBAL_DISPLAY_CORRECTION		"global-display-correction"
+#define GCM_SETTINGS_SET_ICC_PROFILE_ATOM		"set-icc-profile-atom"
+#define GCM_SETTINGS_RENDERING_INTENT_DISPLAY		"rendering-intent-display"
+#define GCM_SETTINGS_RENDERING_INTENT_SOFTPROOF		"rendering-intent-softproof"
+#define GCM_SETTINGS_COLORSPACE_RGB			"colorspace-rgb"
+#define GCM_SETTINGS_COLORSPACE_CMYK			"colorspace-cmyk"
+#define GCM_SETTINGS_USE_PROFILES_FROM_VOLUMES		"use-profiles-from-volumes"
+#define GCM_SETTINGS_CALIBRATION_LENGTH			"calibration-length"
+#define GCM_SETTINGS_SHOW_FINE_TUNING			"show-fine-tuning"
+#define GCM_SETTINGS_SHOW_NOTIFICATIONS			"show-notifications"
+#define GCM_SETTINGS_MIGRATE_CONFIG_VERSION		"migrate-config-version"
+#define GCM_SETTINGS_RECALIBRATE_PRINTER_THRESHOLD	"recalibrate-printer-threshold"
+#define GCM_SETTINGS_RECALIBRATE_DISPLAY_THRESHOLD	"recalibrate-display-threshold"
+#define GCM_SETTINGS_ENABLE_SANE			"enable-sane"
+#define GCM_SETTINGS_ENABLE_CUPS			"enable-cups"
 
-#define GCM_SETTINGS_RECALIBRATE_PRINTER_THRESHOLD	"/apps/gnome-color-manager/recalibrate_printer_threshold"
-#define GCM_SETTINGS_RECALIBRATE_DISPLAY_THRESHOLD	"/apps/gnome-color-manager/recalibrate_display_threshold"
+#define GCM_CONFIG_VERSION_ORIGINAL			0
+#define GCM_CONFIG_VERSION_SHARED_SPEC			1
 
 /* DISTROS: you will have to patch if you have changed the name of these packages */
 #define GCM_PREFS_PACKAGE_NAME_SHARED_COLOR_TARGETS	"shared-color-targets"
@@ -77,6 +85,7 @@ void		 gcm_utils_ensure_printable		(gchar			*text);
 gboolean	 gcm_utils_is_icc_profile		(GFile			*file);
 gchar		*gcm_utils_linkify			(const gchar		*text);
 const gchar	*gcm_intent_to_localized_text		(GcmIntent	 intent);
+const gchar	*gcm_intent_to_localized_description	(GcmIntent	 intent);
 
 #endif /* __GCM_UTILS_H */
 
